summaryrefslogtreecommitdiff
path: root/actions/twittersettings.php
diff options
context:
space:
mode:
Diffstat (limited to 'actions/twittersettings.php')
-rw-r--r--actions/twittersettings.php20
1 files changed, 10 insertions, 10 deletions
diff --git a/actions/twittersettings.php b/actions/twittersettings.php
index 0859ab9d3..563d867a4 100644
--- a/actions/twittersettings.php
+++ b/actions/twittersettings.php
@@ -1,6 +1,6 @@
<?php
/**
* Laconica, the distributed open-source microblogging tool
*
* Settings for Twitter integration
*
@@ -20,14 +20,14 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
* @category Settings
- * @package Laconica
- * @author Evan Prodromou <evan@controlyourself.ca>
- * @copyright 2008-2009 Control Yourself, Inc.
+ * @package StatusNet
+ * @author Evan Prodromou <evan@status.net>
+ * @copyright 2008-2009 StatusNet, Inc.
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
- * @link http://laconi.ca/
+ * @link http://status.net/
*/
-if (!defined('LACONICA')) {
+if (!defined('STATUSNET') && !defined('LACONICA')) {
exit(1);
}
@@ -38,10 +38,10 @@ require_once INSTALLDIR.'/lib/twitter.php';
* Settings for Twitter integration
*
* @category Settings
- * @package Laconica
- * @author Evan Prodromou <evan@controlyourself.ca>
+ * @package StatusNet
+ * @author Evan Prodromou <evan@status.net>
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
- * @link http://laconi.ca/
+ * @link http://status.net/
*
* @see SettingsAction
*/
@@ -75,7 +75,7 @@ class TwittersettingsAction extends ConnectSettingsAction
* Content area of the page
*
* Shows a form for associating a Twitter account with this
* Laconica account. Also lets the user set preferences.
*
* @return void
*/
@@ -1,6 +1,6 @@
<?php
/**
- * Laconica, the distributed open-source microblogging tool
+ * StatusNet, the distributed open-source microblogging tool
*
* Settings for Twitter integration
@@ -75,7 +75,7 @@ class TwittersettingsAction extends ConnectSettingsAction
*
* Shows a form for associating a Twitter account with this
- * Laconica account. Also lets the user set preferences.
+ * StatusNet account. Also lets the user set preferences.
*
* @return void